==> cxf-services-xkms-common-3.4.6-sources.jar: org/apache/cxf/xkms/model/xkms/CompoundResultType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CompoundResultType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CompoundResultType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}ResultType"&gt;
 *       &lt;choice maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}LocateResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidateResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RegisterResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ReissueResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeResult"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompoundResultType", propOrder = {
    "locateResultOrValidateResultOrRegisterResult"
})
public class CompoundResultType
    extends ResultType
{

    @XmlElements({
        @XmlElement(name = "LocateResult", type = LocateResultType.class),
        @XmlElement(name = "ValidateResult", type = ValidateResultType.class),
        @XmlElement(name = "RegisterResult", type = RegisterResultType.class),
        @XmlElement(name = "ReissueResult", type = ReissueResultType.class),
        @XmlElement(name = "RecoverResult", type = RecoverResultType.class),
        @XmlElement(name = "RevokeResult", type = RevokeResultType.class)
    })
    protected List<ResultType> locateResultOrValidateResultOrRegisterResult;

    /**
     * Gets the value of the locateResultOrValidateResultOrRegisterResult property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the locateResultOrValidateResultOrRegisterResult property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLocateResultOrValidateResultOrRegisterResult().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocateResultType }
     * {@link RecoverResultType }
     * {@link RegisterResultType }
     * {@link ReissueResultType }
     * {@link RevokeResultType }
     * {@link ValidateResultType }
     * 
     * 
     */
    public List<ResultType> getLocateResultOrValidateResultOrRegisterResult() {
        if (locateResultOrValidateResultOrRegisterResult == null) {
            locateResultOrValidateResultOrRegisterResult = new ArrayList<ResultType>();
        }
        return this.locateResultOrValidateResultOrRegisterResult;
    }

}

==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/CompoundResultType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlElements;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CompoundResultType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CompoundResultType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}ResultType"&gt;
 *       &lt;choice maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}LocateResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ValidateResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RegisterResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}ReissueResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverResult"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RevokeResult"/&gt;
 *       &lt;/choice&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CompoundResultType", propOrder = {
    "locateResultOrValidateResultOrRegisterResult"
})
public class CompoundResultType
    extends ResultType
{

    @XmlElements({
        @XmlElement(name = "LocateResult", type = LocateResultType.class),
        @XmlElement(name = "ValidateResult", type = ValidateResultType.class),
        @XmlElement(name = "RegisterResult", type = RegisterResultType.class),
        @XmlElement(name = "ReissueResult", type = ReissueResultType.class),
        @XmlElement(name = "RecoverResult", type = RecoverResultType.class),
        @XmlElement(name = "RevokeResult", type = RevokeResultType.class)
    })
    protected List<ResultType> locateResultOrValidateResultOrRegisterResult;

    /**
     * Gets the value of the locateResultOrValidateResultOrRegisterResult property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the locateResultOrValidateResultOrRegisterResult property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLocateResultOrValidateResultOrRegisterResult().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LocateResultType }
     * {@link RecoverResultType }
     * {@link RegisterResultType }
     * {@link ReissueResultType }
     * {@link RevokeResultType }
     * {@link ValidateResultType }
     * 
     * 
     */
    public List<ResultType> getLocateResultOrValidateResultOrRegisterResult() {
        if (locateResultOrValidateResultOrRegisterResult == null) {
            locateResultOrValidateResultOrRegisterResult = new ArrayList<ResultType>();
        }
        return this.locateResultOrValidateResultOrRegisterResult;
    }

}
